@@ -1,4 +1,4 @@
-from CAN_Manager import *
+from TMotorCANControl.CAN_Manager import *
 import can
 import time
 import csv
@@ -6,8 +6,7 @@ import traceback
 from collections import namedtuple
 from enum import Enum
 from math import isfinite
-import StatProfiler
-from SoftRealtimeLoop import SoftRealtimeLoop
+from NeuroLocoMiddleware.SoftRealtimeLoop import SoftRealtimeLoop
 import numpy as np
 import warnings
 
